' ****************************************************************************************
' This example demonstrates the use of the TB_OpenSaveFileName COM class (that wraps the
' API Save and Open file common dialogs). Excepting the instruction to create an instance of
' the class (TB_OpenSaveFileName_CreateInstance instead of [LET] objvar = NEW {DISPATCH | InterfaceName}),
' the use of the class with PB Automation is identical to the one used with any COM component.
' ****************************************************************************************

#COMPILE EXE
#DIM ALL

#INCLUDE "TB_OpenSaveDlg.inc"

%IDC_OPENDIALOG    = 100
%IDC_SAVEDIALOG    = 101

' *****************************************************************************************
' Shows the open file dialog
' *****************************************************************************************
FUNCTION CommonDialogShowOpenDialog (BYVAL hDlg AS DWORD) AS STRING

   LOCAL oOsfn AS DISPATCH ' TB_OpenSaveFileName
   LOCAL vVar AS VARIANT
   LOCAL vRes AS VARIANT

   ' ============================================================
   ' Create an instance of our class
   ' ============================================================
   TB_OpenSaveFileName_CreateInstance(oOsfn)
   IF ISFALSE ISOBJECT(oOsfn) THEN
      MSGBOX "Unable to create an instance of the class"
      EXIT FUNCTION
   END IF

   ' ============================================================
   ' Set some properties
   ' ============================================================
   vVar = "All Files(*.*)|*.*|BAS Files(*.BAS)|*.BAS"
   OBJECT LET oOsfn.Filter = vVar
   vVar = "BAS" : OBJECT LET oOsfn.DefaultExt = vVar
   vVar = 2 AS LONG : OBJECT LET oOsfn.FilterIndex = vVar
   vVar = hDlg AS DWORD : OBJECT LET oOsfn.Parent = vVar
   vVar = -1 AS INTEGER : OBJECT LET oOsfn.ReadOnly = vVar
   vVar = -1 AS INTEGER : OBJECT LET oOsfn.AllowMultiSelect = vVar
   vVar = -1 AS INTEGER : OBJECT LET oOsfn.LongNames = vVar
   vVar = -1 AS INTEGER : OBJECT LET oOsfn.ExplorerStyle = vVar

   ' ============================================================
   ' Show the dialog
   ' ============================================================
   OBJECT CALL oOsfn.ShowOpen TO vRes

   ' ============================================================
   ' Return the selected filename(s)
   ' ============================================================
   OBJECT GET oOsfn.FileName to vRes
   FUNCTION = VARIANT$(vRes)

   ' ============================================================
   ' Release the class
   ' ============================================================
   oOsfn = NOTHING

END FUNCTION
' *****************************************************************************************

' *****************************************************************************************
' Shows the save file dialog
' *****************************************************************************************
FUNCTION CommonDialogShowSaveDialog (BYVAL hDlg AS DWORD, BYVAL strFileName AS STRING) AS STRING

   LOCAL oOsfn AS DISPATCH ' TB_OpenSaveFileName
   LOCAL vVar AS VARIANT
   LOCAL vRes AS VARIANT

   ' ============================================================
   ' Create an instance of our class
   ' ============================================================
   TB_OpenSaveFileName_CreateInstance(oOsfn)
   IF ISFALSE ISOBJECT(oOsfn) THEN
      MSGBOX "Unable to create an instance of the class"
      EXIT FUNCTION
   END IF

   ' ============================================================
   ' Set some properties
   ' ============================================================
   vVar = "All Files(*.*)|*.*|BAS Files(*.BAS)|*.BAS"
   OBJECT LET oOsfn.Filter = vVar
   vVar = "BAS" : OBJECT LET oOsfn.DefaultExt = vVar
   IF LEN(strFIleName) THEN
      vVar = strFIleName : OBJECT LET oOsfn.FileName = vVar
   END IF
   vVar = 2 AS LONG : OBJECT LET oOsfn.FilterIndex = vVar
   vVar = hDlg AS DWORD : OBJECT LET oOsfn.Parent = vVar
   vVar = -1 AS INTEGER : OBJECT LET oOsfn.LongNames = vVar
   vVar = -1 AS INTEGER : OBJECT LET oOsfn.ExplorerStyle = vVar

   ' ============================================================
   ' Show the dialog
   ' ============================================================
   OBJECT CALL oOsfn.ShowSave TO vRes

   ' ============================================================
   ' Return the filename
   ' ============================================================
   OBJECT GET oOsfn.FileName to vRes
   FUNCTION = VARIANT$(vRes)

   ' ============================================================
   ' Release the class
   ' ============================================================
   oOsfn = NOTHING

END FUNCTION
' *****************************************************************************************


' *****************************************************************************************
' Main
' *****************************************************************************************
FUNCTION PBMAIN () AS LONG

   LOCAL hDlg AS LONG

   DIALOG NEW 0, "Common Dialog Test", , , 300, 200, %WS_OVERLAPPED OR %WS_THICKFRAME OR %WS_SYSMENU OR _
   %WS_MINIMIZEBOX OR %WS_MAXIMIZEBOX OR %WS_VISIBLE OR %DS_CENTER TO hDlg

   ' For icon from resource, instead use something like, LoadIcon(hInst, "APPICON")
   DIALOG SEND hDlg, %WM_SETICON, %ICON_SMALL, LoadIcon(%NULL, BYVAL %IDI_APPLICATION)
   DIALOG SEND hDlg, %WM_SETICON, %ICON_BIG, LoadIcon(%NULL, BYVAL %IDI_APPLICATION)

   CONTROL ADD BUTTON, hDlg, %IDC_OPENDIALOG, "Open", 0, 0, 50, 14, %WS_CHILD OR %WS_VISIBLE OR %WS_TABSTOP OR %BS_FLAT
   CONTROL ADD BUTTON, hDlg, %IDC_SAVEDIALOG, "Save", 0, 0, 50, 14, %WS_CHILD OR %WS_VISIBLE OR %WS_TABSTOP OR %BS_FLAT
   CONTROL ADD BUTTON, hDlg, %IDCANCEL, "Close", 0, 0, 50, 14, %WS_CHILD OR %WS_VISIBLE OR %WS_TABSTOP OR %BS_FLAT

   DIALOG SHOW MODAL hDlg, CALL DlgProc

END FUNCTION
' *****************************************************************************************

' *****************************************************************************************
' Main Dialog procedure
' *****************************************************************************************
CALLBACK FUNCTION DlgProc() AS LONG

   LOCAL rc AS RECT
   LOCAL strFileName AS STRING

   SELECT CASE CBMSG

      CASE %WM_SIZE
         ' Resize the two sample buttons of the dialog
         IF CBWPARAM <> %SIZE_MINIMIZED THEN
            GetClientRect CBHNDL, rc
            MoveWindow GetDlgItem(CBHNDL, %IDC_OPENDIALOG), (rc.nRight - rc.nLeft) - 95, (rc.nBottom - rc.nTop) - 235, 75, 23, %TRUE
            MoveWindow GetDlgItem(CBHNDL, %IDC_SAVEDIALOG), (rc.nRight - rc.nLeft) - 95, (rc.nBottom - rc.nTop) - 205, 75, 23, %TRUE
            MoveWindow GetDlgItem(CBHNDL, %IDCANCEL), (rc.nRight - rc.nLeft) - 95, (rc.nBottom - rc.nTop) - 35, 75, 23, %TRUE
            DIALOG REDRAW CBHNDL
         END IF

      CASE %WM_COMMAND
         SELECT CASE CBCTL
            CASE %IDC_OPENDIALOG
               IF CBCTLMSG = %BN_CLICKED THEN
                  strFileName = CommonDialogShowOpenDialog(CBHNDL)
                  IF LEN(strFileName) THEN MSGBOX strFileName
               END IF
            CASE %IDC_SAVEDIALOG
               IF CBCTLMSG = %BN_CLICKED THEN
                  strFileName = CommonDialogShowSaveDialog(CBHNDL, "Test.bas")
                  IF LEN(strFileName) THEN MSGBOX strFileName
               END IF
            CASE %IDCANCEL
               IF CBCTLMSG = %BN_CLICKED THEN DIALOG END CBHNDL, 0
         END SELECT

   END SELECT

END FUNCTION
' *****************************************************************************************
